@@ -11,6 +11,7 @@ import site
 import stat
 import subprocess
 import sys
+import textwrap
 import zipfile
 from collections import OrderedDict
 from itertools import product
@@ -24,11 +25,13 @@ import pytest
 from virtualenv.__main__ import run, run_with_catch
 from virtualenv.create.creator import DEBUG_SCRIPT, Creator, get_env_debug_info
 from virtualenv.create.pyenv_cfg import PyEnvCfg
+from virtualenv.create.via_global_ref import api
 from virtualenv.create.via_global_ref.builtin.cpython.common import is_macos_brew
 from virtualenv.create.via_global_ref.builtin.cpython.cpython3 import CPython3Posix
 from virtualenv.discovery.py_info import PythonInfo
 from virtualenv.info import IS_PYPY, IS_WIN, fs_is_case_sensitive
 from virtualenv.run import cli_run, session_via_cli
+from virtualenv.run.plugin.creators import CreatorSelector
 
 CURRENT = PythonInfo.current_system()
 
@@ -77,13 +80,12 @@ def test_destination_not_write_able(tmp_path, capsys):
 
 
 def cleanup_sys_path(paths):
-    from virtualenv.create.creator import HERE
+    from virtualenv.create.creator import HERE  # noqa: PLC0415
 
     paths = [p.resolve() for p in (Path(os.path.abspath(i)) for i in paths) if p.exists()]
     to_remove = [Path(HERE)]
     if os.environ.get("PYCHARM_HELPERS_DIR"):
-        to_remove.append(Path(os.environ["PYCHARM_HELPERS_DIR"]).parent)
-        to_remove.append(Path(os.path.expanduser("~")) / ".PyCharm")
+        to_remove.extend((Path(os.environ["PYCHARM_HELPERS_DIR"]).parent, Path(os.path.expanduser("~")) / ".PyCharm"))
     return [i for i in paths if not any(str(i).startswith(str(t)) for t in to_remove)]
 
 
@@ -92,9 +94,9 @@ def system(session_app_data):
     return get_env_debug_info(Path(CURRENT.system_executable), DEBUG_SCRIPT, session_app_data, os.environ)
 
 
-CURRENT_CREATORS = [i for i in CURRENT.creators().key_to_class if i != "builtin"]
+CURRENT_CREATORS = [i for i in CreatorSelector.for_interpreter(CURRENT).key_to_class if i != "builtin"]
 CREATE_METHODS = []
-for k, v in CURRENT.creators().key_to_meta.items():
+for k, v in CreatorSelector.for_interpreter(CURRENT).key_to_meta.items():
     if k in CURRENT_CREATORS:
         if v.can_copy:
             if k == "venv" and CURRENT.implementation == "PyPy" and CURRENT.pypy_version_info >= [7, 3, 13]:
@@ -217,7 +219,38 @@ def test_create_no_seed(  # noqa: C901, PLR0912, PLR0913, PLR0915
         assert result == "None"
 
     git_ignore = (dest / ".gitignore").read_text(encoding="utf-8")
-    assert git_ignore.splitlines() == ["# created by virtualenv automatically", "*"]
+    if creator_key == "venv" and sys.version_info >= (3, 13):
+        comment = "# Created by venv; see https://docs.python.org/3/library/venv.html"
+    else:
+        comment = "# created by virtualenv automatically"
+    assert git_ignore.splitlines() == [comment, "*"]
+
+
+def test_create_cachedir_tag(tmp_path):
+    cachedir_tag_file = tmp_path / "CACHEDIR.TAG"
+    cli_run([str(tmp_path), "--without-pip", "--activators", ""])
+
+    expected = """
+    Signature: 8a477f597d28d172789f06886806bc55
+    # This file is a cache directory tag created by Python virtualenv.
+    # For information about cache directory tags, see:
+    #   https://bford.info/cachedir/
+    """
+    assert cachedir_tag_file.read_text(encoding="utf-8") == textwrap.dedent(expected).strip()
+
+
+def test_create_cachedir_tag_exists(tmp_path: Path) -> None:
+    cachedir_tag_file = tmp_path / "CACHEDIR.TAG"
+    cachedir_tag_file.write_text("magic", encoding="utf-8")
+    cli_run([str(tmp_path), "--without-pip", "--activators", ""])
+    assert cachedir_tag_file.read_text(encoding="utf-8") == "magic"
+
+
+def test_create_cachedir_tag_exists_override(tmp_path: Path) -> None:
+    cachedir_tag_file = tmp_path / "CACHEDIR.TAG"
+    cachedir_tag_file.write_text("magic", encoding="utf-8")
+    cli_run([str(tmp_path), "--without-pip", "--activators", ""])
+    assert cachedir_tag_file.read_text(encoding="utf-8") == "magic"
 
 
 def test_create_vcs_ignore_exists(tmp_path):
@@ -367,7 +400,11 @@ def test_create_long_path(tmp_path):
     subprocess.check_call([str(result.creator.script("pip")), "--version"])
 
 
-@pytest.mark.parametrize("creator", sorted(set(PythonInfo.current_system().creators().key_to_class) - {"builtin"}))
+@pytest.mark.slow
+@pytest.mark.parametrize(
+    "creator",
+    sorted(set(CreatorSelector.for_interpreter(PythonInfo.current_system()).key_to_class) - {"builtin"}),
+)
 @pytest.mark.usefixtures("session_app_data")
 def test_create_distutils_cfg(creator, tmp_path, monkeypatch):
     result = cli_run(
@@ -379,8 +416,6 @@ def test_create_distutils_cfg(creator, tmp_path, monkeypatch):
             creator,
             "--setuptools",
             "bundle",
-            "--wheel",
-            "bundle",
         ],
     )
 
@@ -434,6 +469,7 @@ def list_files(path):
 
 
 @pytest.mark.skipif(is_macos_brew(CURRENT), reason="no copy on brew")
+@pytest.mark.skip(reason="https://github.com/pypa/setuptools/issues/4640")
 def test_zip_importer_can_import_setuptools(tmp_path):
     """We're patching the loaders so might fail on r/o loaders, such as zipimporter on CPython<3.8"""
     result = cli_run(
@@ -481,10 +517,9 @@ def test_no_preimport_threading(tmp_path):
 # verify that .pth files in site-packages/ are always processed even if $PYTHONPATH points to it.
 def test_pth_in_site_vs_python_path(tmp_path):
     session = cli_run([str(tmp_path)])
-    site_packages = str(session.creator.purelib)
+    site_packages = session.creator.purelib
     # install test.pth that sets sys.testpth='ok'
-    with open(os.path.join(site_packages, "test.pth"), "w", encoding="utf-8") as f:
-        f.write('import sys; sys.testpth="ok"\n')
+    (session.creator.purelib / "test.pth").write_text('import sys; sys.testpth="ok"\n', encoding="utf-8")
     # verify that test.pth is activated when interpreter is run
     out = subprocess.check_output(
         [str(session.creator.exe), "-c", r"import sys; print(sys.testpth)"],
@@ -494,7 +529,7 @@ def test_pth_in_site_vs_python_path(tmp_path):
     assert out == "ok\n"
     # same with $PYTHONPATH pointing to site_packages
     env = os.environ.copy()
-    path = [site_packages]
+    path = [str(site_packages)]
     if "PYTHONPATH" in env:
         path.append(env["PYTHONPATH"])
     env["PYTHONPATH"] = os.pathsep.join(path)
@@ -646,7 +681,7 @@ def test_python_path(monkeypatch, tmp_path, python_path_on):
 # https://github.com/pypa/virtualenv/issues/2419
 @pytest.mark.skipif("venv" not in CURRENT_CREATORS, reason="test needs venv creator")
 def test_venv_creator_without_write_perms(tmp_path, mocker):
-    from virtualenv.run.session import Session
+    from virtualenv.run.session import Session  # noqa: PLC0415
 
     prev = Session._create  # noqa: SLF001
 
@@ -660,3 +695,63 @@ def test_venv_creator_without_write_perms(tmp_path, mocker):
 
     cmd = [str(tmp_path), "--seeder", "app-data", "--without-pip", "--creator", "venv"]
     cli_run(cmd)
+
+
+def test_fallback_to_copies_if_symlink_unsupported(tmp_path, python, mocker):
+    """Test that creating a virtual environment falls back to copies when filesystem has no symlink support."""
+    if is_macos_brew(PythonInfo.from_exe(python)):
+        pytest.skip("brew python on darwin may not support copies, which is tested separately")
+
+    # Given a filesystem that does not support symlinks
+    mocker.patch("virtualenv.create.via_global_ref.api.fs_supports_symlink", return_value=False)
+
+    # When creating a virtual environment (no method specified)
+    cmd = [
+        "-v",
+        "-p",
+        str(python),
+        str(tmp_path),
+        "--without-pip",
+        "--activators",
+        "",
+    ]
+    result = cli_run(cmd)
+
+    # Then the creation should succeed and the creator should report it used copies
+    assert result.creator is not None
+    assert result.creator.symlinks is False
+
+
+def test_fail_gracefully_if_no_method_supported(tmp_path, python, mocker):
+    """Test that virtualenv fails gracefully when no creation method is supported."""
+    # Given a filesystem that does not support symlinks
+    mocker.patch("virtualenv.create.via_global_ref.api.fs_supports_symlink", return_value=False)
+
+    # And a creator that does not support copying
+    if not is_macos_brew(PythonInfo.from_exe(python)):
+        original_init = api.ViaGlobalRefMeta.__init__
+
+        def new_init(self, *args, **kwargs):
+            original_init(self, *args, **kwargs)
+            self.copy_error = "copying is not supported"
+
+        mocker.patch("virtualenv.create.via_global_ref.api.ViaGlobalRefMeta.__init__", new=new_init)
+
+    # When creating a virtual environment
+    with pytest.raises(RuntimeError) as excinfo:
+        cli_run(
+            [
+                "-p",
+                str(python),
+                str(tmp_path),
+                "--without-pip",
+            ],
+        )
+
+    # Then a RuntimeError should be raised with a detailed message
+    assert "neither symlink or copy method supported" in str(excinfo.value)
+    assert "symlink: the filesystem does not supports symlink" in str(excinfo.value)
+    if is_macos_brew(PythonInfo.from_exe(python)):
+        assert "copy: Brew disables copy creation" in str(excinfo.value)
+    else:
+        assert "copy: copying is not supported" in str(excinfo.value)
