@@ -14,6 +14,7 @@ from typing import NamedTuple
 
 import pytest
 
+from virtualenv.create.via_global_ref.builtin.cpython.common import is_macos_brew
 from virtualenv.discovery import cached_py_info
 from virtualenv.discovery.py_info import PythonInfo, VersionInfo
 from virtualenv.discovery.py_spec import PythonSpec
@@ -154,6 +155,41 @@ def test_py_info_cache_clear(mocker, session_app_data):
     assert spy.call_count >= 2 * count
 
 
+def test_py_info_cache_invalidation_on_py_info_change(mocker, session_app_data):
+    # 1. Get a PythonInfo object for the current executable, this will cache it.
+    PythonInfo.from_exe(sys.executable, session_app_data)
+
+    # 2. Spy on _run_subprocess
+    spy = mocker.spy(cached_py_info, "_run_subprocess")
+
+    # 3. Backup py_info.py
+    py_info_script = Path(cached_py_info.__file__).parent / "py_info.py"
+    original_content = py_info_script.read_text(encoding="utf-8")
+    original_stat = py_info_script.stat()
+
+    try:
+        # 4. Clear the in-memory cache
+        mocker.patch.dict(cached_py_info._CACHE, {}, clear=True)  # noqa: SLF001
+
+        # 5. Modify py_info.py to invalidate the cache
+        py_info_script.write_text(original_content + "\n# a comment", encoding="utf-8")
+
+        # 6. Get the PythonInfo object again
+        info = PythonInfo.from_exe(sys.executable, session_app_data)
+
+        # 7. Assert that _run_subprocess was called again
+        native_difference = 1 if info.system_executable == info.executable else 0
+        if is_macos_brew(info):
+            assert spy.call_count + native_difference in {2, 3}
+        else:
+            assert spy.call_count + native_difference == 2
+
+    finally:
+        # 8. Restore the original content and timestamp
+        py_info_script.write_text(original_content, encoding="utf-8")
+        os.utime(str(py_info_script), (original_stat.st_atime, original_stat.st_mtime))
+
+
 @pytest.mark.skipif(not fs_supports_symlink(), reason="symlink is not supported")
 @pytest.mark.xfail(
     # https://doc.pypy.org/en/latest/install.html?highlight=symlink#download-a-pre-built-pypy
@@ -254,7 +290,7 @@ def test_system_executable_no_exact_match(  # noqa: PLR0913
     mocker.patch.object(target_py_info, "_find_possible_exe_names", return_value=names)
     mocker.patch.object(target_py_info, "_find_possible_folders", return_value=[str(tmp_path)])
 
-    def func(k, app_data, resolve_to_host, raise_on_error, env):  # noqa: ARG001
+    def func(k, app_data, resolve_to_host, raise_on_error, env, cache=None):  # noqa: ARG001, PLR0913
         return discovered_with_path[k]
 
     mocker.patch.object(target_py_info, "from_exe", side_effect=func)
@@ -400,7 +436,9 @@ def test_custom_venv_install_scheme_is_prefered(mocker):
     assert pyinfo.install_path("purelib").replace(os.sep, "/") == f"lib/python{pyver}/site-packages"
 
 
-@pytest.mark.skipif(not (os.name == "posix" and sys.version_info[:2] >= (3, 11)), reason="POSIX 3.11+ specific")
+@pytest.mark.skipif(
+    IS_PYPY or not (os.name == "posix" and sys.version_info[:2] >= (3, 11)), reason="POSIX 3.11+ specific"
+)
 def test_fallback_existent_system_executable(mocker):
     current = PythonInfo()
     # Posix may execute a "python" out of a venv but try to set the base_executable
@@ -416,11 +454,11 @@ def test_fallback_existent_system_executable(mocker):
     mocker.patch.object(sys, "executable", current.executable)
 
     # ensure it falls back to an alternate binary name that exists
-    current._fast_get_system_executable()  # noqa: SLF001
-    assert os.path.basename(current.system_executable) in [
+    system_executable = current._fast_get_system_executable()  # noqa: SLF001
+    assert os.path.basename(system_executable) in [
         f"python{v}" for v in (current.version_info.major, f"{current.version_info.major}.{current.version_info.minor}")
     ]
-    assert os.path.exists(current.system_executable)
+    assert os.path.exists(system_executable)
 
 
 @pytest.mark.skipif(sys.version_info[:2] != (3, 10), reason="3.10 specific")
